
local sounds = {}
sounds["begin"] = love.audio.newSource("assets/metalhit.ogg", "static")
sounds["northeast"] = love.audio.newSource("assets/northeast.ogg", "static")
sounds["northwest"] = love.audio.newSource("assets/northwest.ogg", "static")
sounds["southeast"] = love.audio.newSource("assets/southeast.ogg", "static")
sounds["southwest"] = love.audio.newSource("assets/southwest.ogg", "static")
sounds["hit"] = love.audio.newSource("assets/hit.ogg", "static")
sounds["shoot"] = love.audio.newSource("assets/shoot.ogg", "static")
sounds["punch"] = love.audio.newSource("assets/punch.ogg", "static")

sounds["begin"]:setVolume(.7)
sounds["northwest"]:setVolume(1)
sounds["northeast"]:setVolume(1)
sounds["southwest"]:setVolume(1)
sounds["southeast"]:setVolume(1)
sounds["hit"]:setVolume(.5)
sounds["shoot"]:setVolume(0.2)
sounds["punch"]:setVolume(1)

local songs = {}

local logos = {}
logos[1] = love.graphics.newImage("assets/mainlogo.png")
logos[2] = love.graphics.newImage("assets/ungraphixlogo.png")
logos[3] = love.graphics.newImage("assets/zombiedoomlogo.png")

local player = {}
player.x = 0
player.y = 0
player.speed = 80
player.health = 100
player.h_timer = 0

local zombies = {}
local bullets = {}

local time = 0
local level = 1

local state = "logos"
local logotimer = 0

local debug = false

function dist(x1,y1, x2,y2) return ((x2-x1)^2+(y2-y1)^2)^0.5 end

function createZombie(health)
  local z = {}
  z.health = health
  z.x = love.math.random(level*-500, level*500)
  z.y = love.math.random(level*-500, level*500)
  z.speed = 10
  z.triggered = false
  table.insert(zombies, z)
end

function shoot(dir)
  local b = {}
  b.x = player.x
  b.y = player.y
  b.dir = dir
  b.speed = 100
  table.insert(bullets, b)

  sounds["shoot"]:stop()
  sounds["shoot"]:play()
end

function love.update(dt)
  if state == "logos" then
    if logotimer < 2 then
      logotimer = logotimer + dt
    else
      for i=1, level*20 do
        createZombie(level)
        sounds["begin"]:play()
      end
      state = "game"
    end
  elseif state == "game" then
    -- Handle Levels
    time = time + dt
    if time > level*10 then
      for i=1, level*10 do
        createZombie(level)
        sounds["begin"]:play()
      end
      level = level + 1
      time = 0
    end

    -- Handle Zombies
    for i,v in ipairs(zombies) do
      if player.x > v.x then
        v.x = v.x + v.speed*dt
        v.x_pos = "west"
      elseif player.x < v.x then
        v.x = v.x - v.speed*dt
        v.x_pos = "east"
      end
      if player.y > v.y then
        v.y = v.y + v.speed*dt
        v.y_pos = "north"
      elseif player.y < v.y then
        v.y = v.y - v.speed*dt
        v.y_pos = "south"
      end

      -- Check collision with bullets
      for x, y in ipairs(bullets) do
        local dis = dist(y.x, y.y, v.x, v.y)
        if dis < 30 then
          sounds["hit"]:stop()
          sounds["hit"]:play()
          v.health = v.health - 1
        end

        if y.dir == "up" then
          y.y = y.y - y.speed*dt
        elseif y.dir == "down" then
          y.y = y.y + y.speed*dt
        elseif y.dir == "left" then
          y.x = y.x - y.speed*dt
        elseif y.dir == "right" then
          y.x = y.x + y.speed*dt
        end

        local dis2 = dist(y.x, y.y, player.x, player.y)
        if dis2 > 1000 then
          table.remove(bullets, x)
        end
      end

      -- Check distance
      local dis = dist(v.x, v.y, player.x, player.y)

      if dis < 50 and dis > 10 then
        if v.triggered == false then
          print(v.x_pos, v.y_pos)
          if v.x_pos == "west" and v.y_pos == "north" then
            sounds["northwest"]:stop()
            sounds["northwest"]:play()
          elseif v.x_pos == "east" and v.y_pos == "north" then
            sounds["northeast"]:stop()
            sounds["northeast"]:play()
          elseif v.x_pos == "west" and v.y_pos == "south" then
            sounds["southwest"]:stop()
            sounds["southwest"]:play()
          elseif v.x_pos == "east" and v.y_pos == "south" then
            sounds["southeast"]:stop()
            sounds["southeast"]:play()
          end
          v.triggered = true
        end
      elseif dist(v.x, v.y, player.x, player.y) < 10 then
        player.health = player.health - dt
        -- play health sound
        player.h_timer = player.h_timer + dt
        if player.h_timer > 1 then
          sounds["punch"]:stop()
          sounds["punch"]:play()
          player.h_timer = 0
        end
      end

      -- Check Zombie Health
      if v.health <= 0 then
        table.remove(zombies, i)
      end
    end

    -- Handle Player Movement
    if love.keyboard.isDown("w") then
      player.y = player.y - player.speed*dt
    end
    if love.keyboard.isDown("s") then
      player.y = player.y + player.speed*dt
    end
    if love.keyboard.isDown("a") then
      player.x = player.x - player.speed*dt
    end
    if love.keyboard.isDown("d") then
      player.x = player.x + player.speed*dt
    end

    if player.health < 0 then
      logotimer = 0
      zombies = {}
      player.x = 0
      player.y = 0
      player.health = 100
      level = 1
      state = "logos"
    end

  end
end

function love.draw()
  if state == "logos" then
    if logotimer < 1 then
      love.graphics.draw(logos[1], 0, 0)
    elseif logotimer > 1 and logotimer < 2 then
      love.graphics.draw(logos[2], 0, 0)
    end
  else
    love.graphics.draw(logos[3], 0, 0)
    if debug then
      love.graphics.setColor(0, 0, 0)
      for i,v in ipairs(zombies) do
        love.graphics.print("Z", v.x, v.y)
      end
      for i,v in ipairs(bullets) do
        love.graphics.print("*", v.x, v.y)
      end
      love.graphics.print("P", player.x, player.y)
    end
    love.graphics.setColor(255,255,255)
  end
end

function love.keypressed(key)
  if key == "up" then
    shoot("up")
  elseif key == "down" then
    shoot("down")
  elseif key == "left" then
    shoot("left")
  elseif key == "right" then
    shoot("right")
  elseif key == "`" then
    debug = not debug
  end
end
